=========
PauliCirc
=========

.. image:: https://img.shields.io/badge/python-3.10+-green.svg
    :target: https://docs.python.org/3.10/
    :alt: Python versions

.. image:: https://img.shields.io/pypi/v/paulicirc.svg
    :target: https://pypi.python.org/pypi/paulicirc/
    :alt: PyPI version

.. image:: https://img.shields.io/pypi/status/paulicirc.svg
    :target: https://pypi.python.org/pypi/paulicirc/
    :alt: PyPI status

.. image:: http://www.mypy-lang.org/static/mypy_badge.svg
    :target: https://github.com/python/mypy
    :alt: Checked with Mypy

.. image:: https://readthedocs.org/projects/paulicirc/badge/?version=latest
    :target: https://paulicirc.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status


.. contents::


PauliCirc is a library for the vectorized creation and manipulation of quantum circuits consisting of Pauli gadgets.
The library is in alpha stage and active development, so please be mindful that bugs are possible at this stage.

Install
=======

You can install the latest release from `PyPI <https://pypi.org/project/dag-cbor/>`_ as follows:

.. code-block:: console

    $ pip install --upgrade paulicirc


Usage
=====

For an overview of library features and usage, see https://paulicirc.readthedocs.io/en/latest/getting-started.html


API
===

For the full API documentation, see https://paulicirc.readthedocs.io/


License
=======

`LGPLv3 © NeverLocal. <LICENSE>`_

